@@ -13,6 +13,4 @@ pref("app.normandy.enabled",               false);
    so corporations can easily turn it back on if there's demand for that */
 pref("permissions.manager.remote.enabled", false);
 pref("spellchecker.dictionary_path", "/usr/share/myspell");
-pref("media.gmp-gmpopenh264.autoupdate", false);
-pref("media.gmp-widevinecdm.autoupdate", false);
 sticky_pref("gfx.font_rendering.graphite.enabled", true);
